@@ -29,7 +29,7 @@ def cli(obj, quiet=False, debug=False, queue=None):
             logging.basicConfig(level=logging.INFO)
 
     if queue is None:
-        queue = os.environ.get('DQUEUE_LEADER', None)
+        queue = os.environ.get('ODAHUB', None)
 
     obj['queue'] = from_uri(queue)
     logger.info("using queue: %s", obj['queue'])
@@ -227,11 +227,13 @@ def assert_fact(obj, dag, data):
     dag = json.load(dag)
     data = json.load(data)
 
-    obj['queue'].assert_fact(
+    r = obj['queue'].assert_fact(
                 dag=dag,
                 data=data,
             )
 
+    print("assert_fact returns", r)
+
 @datacli.command()
 @click.pass_obj
 @click.option("-g", "--dag", type=click.File('rt'))
